/**
 * prende in ingresso il codice sorgente di http://www.seriesyonkis.com/lista-series.php
 * e produce un array con la lista delle serie disponibili
 * array([nome serie] => [id serie in seriesyonkis])
 */
function parseHtmlToSeriesArray(html)
{
	//var regexp = /<li class="page_item_">.*?<\/li>/gi;
	var array_matches = html.match(/<li class="page_item_">.*?<\/li>/gi);
	
	return array_matches;
}

/**
 * toglie gli spazi a destra e a sinistra
 * @param text
 * @returns
 */
function trim(text)
{
	return text.replace(/^\s+|\s+$/g,"");
}

/**
 * prende in ingresso una data in formato YYYY-MM-DD e la converte in DD/MM/YYYY
 * @param date
 */
function parseDate(date)
{
	var output = '';
	
	if (date.length >= 10)
	{
		output += date.substr(8,2);	// DD
		output += '/';
		output += date.substr(5,2);	// MM
		output += '/';
		output += date.substr(0,4);	// YYYY
	}
	
	return output;
}


/**
 * verifica che un elemento sia in un array
 * @param needle
 * @param haystack
 * @returns {Boolean}
 */
function inArray(needle, haystack) {
    var length = haystack.length;
    for(var i = 0; i < length; i++) {
        if(haystack[i] == needle) return true;
    }
    return false;
}

/**
 * controlla che la pagina dellala pubblicità admob contenga effettivamente una pubblicità
 * evita di visualizzare la view dell'ad se c'è solo l'immagine 1x1 pixel
 * @param text
 * @returns {Boolean}
 */
function contains_ad(text)
{
	// controllo che nella stringa text ci sia la stringa 'height="48"'
	if (null != text.match(/height="48"/)) { return true; }
	
	return false;
}


/*
 * This will parse a delimited string into an array of 
 * arrays. The default delimiter is the comma, but this
 * can be overriden in the second argument.
 * 
 * presa da: http://stackoverflow.com/questions/1293147/javascript-code-to-parse-csv-data
 */
function CSVToArray(filename, strDelimiter)
{
    // Create an array to hold our data. Give the array
    // a default empty first row.
    var arrData = [[]];
    
	file = Titanium.Filesystem.getFile(Titanium.Filesystem.applicationDataDirectory, filename);
	if (file.exists())
	{
		var content = file.read();
		var strdata = content.text;
		
		Titanium.API.info(strData);
		
	    // Check to see if the delimiter is defined. If not,
	    // then default to comma.
	    strDelimiter = (strDelimiter || ",");
	
	    // Create a regular expression to parse the CSV values.
	    
	    	var objPattern = new RegExp(
	    		(
	                    // Delimiters.
	                    "(\\" + strDelimiter + "|\\r?\\n|\\r|^)" +
	
	                    // Quoted fields.
	                    "(?:\"([^\"]*(?:\"\"[^\"]*)*)\"|" +
	
	                    // Standard fields.
	                    "([^\"\\" + strDelimiter + "\\r\\n]*))"
	            ), "gi"
	    	);
	    
	    //Titanium.API.info(objPattern.source);
	
	

	
	    // Create an array to hold our individual pattern
	    // matching groups.
	    var arrMatches = null;
	
	
	    // Keep looping over the regular expression matches
	    // until we can no longer find a match.
	    while (arrMatches = objPattern.exec( strData )){
	
	    	// Get the delimiter that was found.
            var strMatchedDelimiter = arrMatches[ 1 ];

            // Check to see if the given delimiter has a length
            // (is not the start of string) and if it matches
            // field delimiter. If id does not, then we know
            // that this delimiter is a row delimiter.
            if ( strMatchedDelimiter.length && (strMatchedDelimiter != strDelimiter) )
            {
            	// Since we have reached a new row of data,
            	// add an empty row to our data array.
            	arrData.push( [] );

            }

            // Now that we have our delimiter out of the way,
            // let's check to see which kind of value we
            // captured (quoted or unquoted).
            if (arrMatches[ 2 ])
            {
                    // We found a quoted value. When we capture
                    // this value, unescape any double quotes.
                    var strMatchedValue = arrMatches[ 2 ].replace(
                            new RegExp( "\"\"", "g" ),
                            "\""
                    );
            } else {
            	// We found a non-quoted value.
            	var strMatchedValue = arrMatches[ 3 ];
            }


            // Now that we have our value string, let's add
            // it to the data array.
            Titanium.API.info('strmv: '+strMatchedValue);
            arrData[ arrData.length - 1 ].push( strMatchedValue );
	    }
	}
	// Return the parsed data.
	return( arrData );
}

/**
 * rimuove gli accenti
 * @param strAccents
 * @returns
 */
function removeAccents(strAccents){
    strAccents = strAccents.split('');
    strAccentsOut = new Array();
    strAccentsLen = strAccents.length;
    var accents = 'ÀÁÂÃÄÅàáâãäåÒÓÔÕÕÖØòóôõöøÈÉÊËèéêëðÇçÐÌÍÎÏìíîïÙÚÛÜùúûüÑñŠšŸÿýŽž';
    var accentsOut = ['A','A','A','A','A','A','a','a','a','a','a','a','O','O','O','O','O','O','O','o','o','o','o','o','o','E','E','E','E','e','e','e','e','e','C','c','D','I','I','I','I','i','i','i','i','U','U','U','U','u','u','u','u','N','n','S','s','Y','y','y','Z','z'];
    for (var y = 0; y < strAccentsLen; y++) {
        if (accents.indexOf(strAccents[y]) != -1) {
            strAccentsOut[y] = accentsOut[accents.indexOf(strAccents[y])];
        }
        else
            strAccentsOut[y] = strAccents[y];
    }
    strAccentsOut = strAccentsOut.join('');
    return strAccentsOut;
}